# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/literati',
                'doc_host': 'https://radekosmulski.github.io',
                'git_url': 'https://github.com/radekosmulski/literati',
                'lib_path': 'literati'},
  'syms': { 'literati.core': { 'literati.core.MarkdownHandler': ('core.html#markdownhandler', 'literati/core.py'),
                               'literati.core.MarkdownHandler.__init__': ('core.html#markdownhandler.__init__', 'literati/core.py'),
                               'literati.core.MarkdownHandler.extract_code': ('core.html#markdownhandler.extract_code', 'literati/core.py'),
                               'literati.core.MarkdownHandler.on_created': ('core.html#markdownhandler.on_created', 'literati/core.py'),
                               'literati.core.MarkdownHandler.on_modified': ('core.html#markdownhandler.on_modified', 'literati/core.py'),
                               'literati.core.MarkdownHandler.process_markdown': ( 'core.html#markdownhandler.process_markdown',
                                                                                   'literati/core.py'),
                               'literati.core.MarkdownHandler.should_process': ( 'core.html#markdownhandler.should_process',
                                                                                 'literati/core.py')}}}
